pitchtools.spell_chromatic_interval_number
==========================================

.. autofunction:: abjad.tools.pitchtools.spell_chromatic_interval_number.spell_chromatic_interval_number
   :noindex:
